================
Reference guides
================


Design reference
================

.. toctree::
    :maxdepth: 2

    design


Change log history
==================

.. toctree::
    :maxdepth: 1

    changelog


Glossary of terms
=================

.. toctree::

    glossary


API reference
=============

.. toctree::
    :maxdepth: 2

    api/icalendar

